@@ -169,3 +169,35 @@ validateFacet <- function(facet, result, call = parent.frame()) {
 
   return(invisible(NULL))
 }
+
+#' @noRd
+validateBackground <- function(background, call = parent.frame()) {
+  msg <- "'background' must be either TRUE/FALSE or a path to an existing `.md` file."
+  if (is.logical(background)) {
+    omopgenerics::assertLogical(background, length = 1, call = call, msg = msg)
+  } else if (is.character(background)) {
+    omopgenerics::assertCharacter(background, length = 1, call = call, msg = msg)
+    if (!file.exists(background)) {
+      cli::cli_abort(message = msg, call = call)
+    }
+  } else {
+    cli::cli_abort(message = msg, call = call)
+  }
+  return(invisible(background))
+}
+
+#' @noRd
+validateSample <- function( sample, call = parent.frame()) {
+  if(!is.null(sample)) {
+  msg <- "'sample' must be either an integer or the name of an existing cohort in the cdm"
+  if (is.numeric(sample)) {
+    omopgenerics::assertNumeric(sample,integerish = TRUE, min = 1, length = 1, null = TRUE, call = call, msg = msg)
+  } else if (is.character(sample)) {
+    omopgenerics::assertCharacter(sample, length = 1, call = call, msg = msg)
+  } else {
+    cli::cli_abort(message = msg, call = call)
+  }
+  }
+  return(invisible(sample))
+}
+
