@@ -1,24 +1,36 @@
-#' Create a visual table from a summarise_omop_snapshot result.
-#' @param result  Output from summariseOmopSnapshot().
-#' @param  type Type of formatting output table. See `visOmopResults::tableType()` for allowed options. Default is `"gt"`.
-#' @return A formatted table object with the summarised data.
+
+#' Create a visual table from a summarise_omop_snapshot result
+#'
+#' @param result A summarised_result object (output of `summariseOmopSnapshot()`
+#' ).
+#' @inheritParams style-table
+#'
+#' @return A formatted table visualisation.
 #' @export
+#'
 #' @examples
 #' \donttest{
-#' cdm <- mockOmopSketch(numberIndividuals = 10)
+#' library(OmopSketch)
+#' library(omock)
+#'
+#' cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")
 #'
 #' result <- summariseOmopSnapshot(cdm = cdm)
 #'
 #' tableOmopSnapshot(result = result)
 #'
-#' PatientProfiles::mockDisconnect(cdm)
+#' cdmDisconnect(cdm = cdm)
 #' }
+#'
 tableOmopSnapshot <- function(result,
-                              type = "gt") {
+                              type = NULL,
+                              style = NULL) {
   # initial checks
   rlang::check_installed("visOmopResults")
   omopgenerics::validateResultArgument(result)
-  omopgenerics::assertChoice(type, visOmopResults::tableType())
+  style <- validateStyle(style = style, obj = "table")
+  type <- validateType(type)
+
 
   # subset to result_type of interest
   result <- result |>
@@ -32,12 +44,16 @@ tableOmopSnapshot <- function(result,
     return(emptyTable(type))
   }
 
-  header <- c("cdm_name")
+  setting_cols <- omopgenerics::settingsColumns(result)
+  setting_cols <- setting_cols[!setting_cols %in% c("study_period_end", "study_period_start")]
 
+  header <- c("cdm_name", setting_cols)
+  cdms <- result$cdm_name |> unique()
   result <- result |>
     formatColumn(c("variable_name", "estimate_name")) |>
     visOmopResults::visOmopTable(
       type = type,
+      style = style,
       hide = c("variable_level"),
       estimateName = c("N" = "<Count>"),
       header = header,
@@ -46,14 +62,19 @@ tableOmopSnapshot <- function(result,
         "Estimate" = "estimate_name",
         "Variable" = "variable_name"
       ),
-      groupColumn = "variable_name"
+      groupColumn = "variable_name",
+      settingsColumn = setting_cols,
+      .options = list(caption = paste0("Snapshot of the cdm ", paste(cdms, collapse = ", ")))
     )
 
   return(result)
 }
 
 warnEmpty <- function(resultType) {
-  cli::cli_warn("`result` does not contain any `{resultType}` data.")
+  message <- "`result` does not contain any `{resultType}` data." |>
+    stringr::str_glue()
+  cli::cli_warn(message = message)
+  return(message)
 }
 emptyTable <- function(type) {
   pkg <- type
@@ -78,9 +99,3 @@ formatColumn <- function(result, col) {
   }
   return(result)
 }
-emptyPlot <- function(type = "ggplot2", title = NULL, subtitle = NULL) {
-  if (type == "ggplot2") {
-    ggplot2::ggplot() +
-      ggplot2::labs(title = title, subtitle = subtitle)
-  }
-}
